# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignErrorValue = typing___NewType("CampaignErrorValue", builtin___int)
    type___CampaignErrorValue = CampaignErrorValue
    CampaignError: _CampaignError
    class _CampaignError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignErrorEnum.CampaignErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(CampaignErrorEnum.CampaignErrorValue, 0)
        UNKNOWN = typing___cast(CampaignErrorEnum.CampaignErrorValue, 1)
        CANNOT_TARGET_CONTENT_NETWORK = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 3
        )
        CANNOT_TARGET_SEARCH_NETWORK = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 4
        )
        CANNOT_TARGET_SEARCH_NETWORK_WITHOUT_GOOGLE_SEARCH = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 5
        )
        CANNOT_TARGET_GOOGLE_SEARCH_FOR_CPM_CAMPAIGN = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 6
        )
        CAMPAIGN_MUST_TARGET_AT_LEAST_ONE_NETWORK = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 7
        )
        CANNOT_TARGET_PARTNER_SEARCH_NETWORK = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 8
        )
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CRITERIA_LEVEL_BIDDING_STRATEGY = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 9
        )
        CAMPAIGN_DURATION_MUST_CONTAIN_ALL_RUNNABLE_TRIALS = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 10
        )
        CANNOT_MODIFY_FOR_TRIAL_CAMPAIGN = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 11
        )
        DUPLICATE_CAMPAIGN_NAME = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 12
        )
        INCOMPATIBLE_CAMPAIGN_FIELD = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 13
        )
        INVALID_CAMPAIGN_NAME = typing___cast(CampaignErrorEnum.CampaignErrorValue, 14)
        INVALID_AD_SERVING_OPTIMIZATION_STATUS = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 15
        )
        INVALID_TRACKING_URL = typing___cast(CampaignErrorEnum.CampaignErrorValue, 16)
        CANNOT_SET_BOTH_TRACKING_URL_TEMPLATE_AND_TRACKING_SETTING = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 17
        )
        MAX_IMPRESSIONS_NOT_IN_RANGE = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 18
        )
        TIME_UNIT_NOT_SUPPORTED = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 19
        )
        INVALID_OPERATION_IF_SERVING_STATUS_HAS_ENDED = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 20
        )
        BUDGET_CANNOT_BE_SHARED = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 21
        )
        CAMPAIGN_CANNOT_USE_SHARED_BUDGET = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 22
        )
        CANNOT_CHANGE_BUDGET_ON_CAMPAIGN_WITH_TRIALS = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 23
        )
        CAMPAIGN_LABEL_DOES_NOT_EXIST = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 24
        )
        CAMPAIGN_LABEL_ALREADY_EXISTS = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 25
        )
        MISSING_SHOPPING_SETTING = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 26
        )
        INVALID_SHOPPING_SALES_COUNTRY = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 27
        )
        ADVERTISING_CHANNEL_TYPE_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 31
        )
        INVALID_ADVERTISING_CHANNEL_SUB_TYPE = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 32
        )
        AT_LEAST_ONE_CONVERSION_MUST_BE_SELECTED = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 33
        )
        CANNOT_SET_AD_ROTATION_MODE = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 34
        )
        CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 35
        )
        CANNOT_SET_DATE_TO_PAST = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 36
        )
        MISSING_HOTEL_CUSTOMER_LINK = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 37
        )
        INVALID_HOTEL_CUSTOMER_LINK = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 38
        )
        MISSING_HOTEL_SETTING = typing___cast(CampaignErrorEnum.CampaignErrorValue, 39)
        CANNOT_USE_SHARED_CAMPAIGN_BUDGET_WHILE_PART_OF_CAMPAIGN_GROUP = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 40
        )
        APP_NOT_FOUND = typing___cast(CampaignErrorEnum.CampaignErrorValue, 41)
        SHOPPING_ENABLE_LOCAL_NOT_SUPPORTED_FOR_CAMPAIGN_TYPE = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 42
        )
        MERCHANT_NOT_ALLOWED_FOR_COMPARISON_LISTING_ADS = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 43
        )
        INSUFFICIENT_APP_INSTALLS_COUNT = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 44
        )
        SENSITIVE_CATEGORY_APP = typing___cast(CampaignErrorEnum.CampaignErrorValue, 45)
    UNSPECIFIED = typing___cast(CampaignErrorEnum.CampaignErrorValue, 0)
    UNKNOWN = typing___cast(CampaignErrorEnum.CampaignErrorValue, 1)
    CANNOT_TARGET_CONTENT_NETWORK = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 3
    )
    CANNOT_TARGET_SEARCH_NETWORK = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 4
    )
    CANNOT_TARGET_SEARCH_NETWORK_WITHOUT_GOOGLE_SEARCH = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 5
    )
    CANNOT_TARGET_GOOGLE_SEARCH_FOR_CPM_CAMPAIGN = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 6
    )
    CAMPAIGN_MUST_TARGET_AT_LEAST_ONE_NETWORK = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 7
    )
    CANNOT_TARGET_PARTNER_SEARCH_NETWORK = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 8
    )
    CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CRITERIA_LEVEL_BIDDING_STRATEGY = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 9
    )
    CAMPAIGN_DURATION_MUST_CONTAIN_ALL_RUNNABLE_TRIALS = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 10
    )
    CANNOT_MODIFY_FOR_TRIAL_CAMPAIGN = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 11
    )
    DUPLICATE_CAMPAIGN_NAME = typing___cast(CampaignErrorEnum.CampaignErrorValue, 12)
    INCOMPATIBLE_CAMPAIGN_FIELD = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 13
    )
    INVALID_CAMPAIGN_NAME = typing___cast(CampaignErrorEnum.CampaignErrorValue, 14)
    INVALID_AD_SERVING_OPTIMIZATION_STATUS = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 15
    )
    INVALID_TRACKING_URL = typing___cast(CampaignErrorEnum.CampaignErrorValue, 16)
    CANNOT_SET_BOTH_TRACKING_URL_TEMPLATE_AND_TRACKING_SETTING = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 17
    )
    MAX_IMPRESSIONS_NOT_IN_RANGE = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 18
    )
    TIME_UNIT_NOT_SUPPORTED = typing___cast(CampaignErrorEnum.CampaignErrorValue, 19)
    INVALID_OPERATION_IF_SERVING_STATUS_HAS_ENDED = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 20
    )
    BUDGET_CANNOT_BE_SHARED = typing___cast(CampaignErrorEnum.CampaignErrorValue, 21)
    CAMPAIGN_CANNOT_USE_SHARED_BUDGET = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 22
    )
    CANNOT_CHANGE_BUDGET_ON_CAMPAIGN_WITH_TRIALS = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 23
    )
    CAMPAIGN_LABEL_DOES_NOT_EXIST = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 24
    )
    CAMPAIGN_LABEL_ALREADY_EXISTS = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 25
    )
    MISSING_SHOPPING_SETTING = typing___cast(CampaignErrorEnum.CampaignErrorValue, 26)
    INVALID_SHOPPING_SALES_COUNTRY = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 27
    )
    ADVERTISING_CHANNEL_TYPE_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 31
    )
    INVALID_ADVERTISING_CHANNEL_SUB_TYPE = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 32
    )
    AT_LEAST_ONE_CONVERSION_MUST_BE_SELECTED = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 33
    )
    CANNOT_SET_AD_ROTATION_MODE = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 34
    )
    CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 35
    )
    CANNOT_SET_DATE_TO_PAST = typing___cast(CampaignErrorEnum.CampaignErrorValue, 36)
    MISSING_HOTEL_CUSTOMER_LINK = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 37
    )
    INVALID_HOTEL_CUSTOMER_LINK = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 38
    )
    MISSING_HOTEL_SETTING = typing___cast(CampaignErrorEnum.CampaignErrorValue, 39)
    CANNOT_USE_SHARED_CAMPAIGN_BUDGET_WHILE_PART_OF_CAMPAIGN_GROUP = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 40
    )
    APP_NOT_FOUND = typing___cast(CampaignErrorEnum.CampaignErrorValue, 41)
    SHOPPING_ENABLE_LOCAL_NOT_SUPPORTED_FOR_CAMPAIGN_TYPE = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 42
    )
    MERCHANT_NOT_ALLOWED_FOR_COMPARISON_LISTING_ADS = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 43
    )
    INSUFFICIENT_APP_INSTALLS_COUNT = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 44
    )
    SENSITIVE_CATEGORY_APP = typing___cast(CampaignErrorEnum.CampaignErrorValue, 45)
    type___CampaignError = CampaignError
    def __init__(self,) -> None: ...

type___CampaignErrorEnum = CampaignErrorEnum



from typing import Any, Optional

class RemarketingActionServiceStub:
    GetRemarketingAction: Any = ...
    MutateRemarketingActions: Any = ...
    def __init__(self, channel: Any) -> None: ...

class RemarketingActionServiceServicer:
    def GetRemarketingAction(self, request: Any, context: Any) -> None: ...
    def MutateRemarketingActions(self, request: Any, context: Any) -> None: ...

def add_RemarketingActionServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...

class RemarketingActionService:
    @staticmethod
    def GetRemarketingAction(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def MutateRemarketingActions(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



from typing import Any, Optional

class CustomerClientLinkServiceStub:
    GetCustomerClientLink: Any = ...
    MutateCustomerClientLink: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomerClientLinkServiceServicer:
    def GetCustomerClientLink(self, request: Any, context: Any) -> None: ...
    def MutateCustomerClientLink(self, request: Any, context: Any) -> None: ...

def add_CustomerClientLinkServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...

class CustomerClientLinkService:
    @staticmethod
    def GetCustomerClientLink(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def MutateCustomerClientLink(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



from typing import Any

class AgeRangeViewServiceStub:
    GetAgeRangeView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AgeRangeViewServiceServicer:
    def GetAgeRangeView(self, request: Any, context: Any) -> None: ...

def add_AgeRangeViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



from typing import Any

class UserListServiceStub:
    GetUserList: Any = ...
    MutateUserLists: Any = ...
    def __init__(self, channel: Any) -> None: ...

class UserListServiceServicer:
    def GetUserList(self, request: Any, context: Any) -> None: ...
    def MutateUserLists(self, request: Any, context: Any) -> None: ...

def add_UserListServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.tracking_code_page_format_pb2 import (
    TrackingCodePageFormatEnum as google___ads___googleads___v4___enums___tracking_code_page_format_pb2___TrackingCodePageFormatEnum,
)
from google.ads.google_ads.v4.proto.enums.tracking_code_type_pb2 import (
    TrackingCodeTypeEnum as google___ads___googleads___v4___enums___tracking_code_type_pb2___TrackingCodeTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TagSnippet(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___tracking_code_type_pb2___TrackingCodeTypeEnum.TrackingCodeTypeValue = ...
    page_format: google___ads___googleads___v4___enums___tracking_code_page_format_pb2___TrackingCodePageFormatEnum.TrackingCodePageFormatValue = ...
    @property
    def global_site_tag(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def event_snippet(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___tracking_code_type_pb2___TrackingCodeTypeEnum.TrackingCodeTypeValue
        ] = None,
        page_format: typing___Optional[
            google___ads___googleads___v4___enums___tracking_code_page_format_pb2___TrackingCodePageFormatEnum.TrackingCodePageFormatValue
        ] = None,
        global_site_tag: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        event_snippet: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "event_snippet", b"event_snippet", "global_site_tag", b"global_site_tag"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "event_snippet",
            b"event_snippet",
            "global_site_tag",
            b"global_site_tag",
            "page_format",
            b"page_format",
            "type",
            b"type",
        ],
    ) -> None: ...

type___TagSnippet = TagSnippet



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LinkedAccountTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LinkedAccountTypeValue = typing___NewType("LinkedAccountTypeValue", builtin___int)
    type___LinkedAccountTypeValue = LinkedAccountTypeValue
    LinkedAccountType: _LinkedAccountType
    class _LinkedAccountType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LinkedAccountTypeEnum.LinkedAccountTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 0)
        UNKNOWN = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 1)
        THIRD_PARTY_APP_ANALYTICS = typing___cast(
            LinkedAccountTypeEnum.LinkedAccountTypeValue, 2
        )
        DATA_PARTNER = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 3)
        GOOGLE_ADS = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 4)
    UNSPECIFIED = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 0)
    UNKNOWN = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 1)
    THIRD_PARTY_APP_ANALYTICS = typing___cast(
        LinkedAccountTypeEnum.LinkedAccountTypeValue, 2
    )
    DATA_PARTNER = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 3)
    GOOGLE_ADS = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 4)
    type___LinkedAccountType = LinkedAccountType
    def __init__(self,) -> None: ...

type___LinkedAccountTypeEnum = LinkedAccountTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PricePlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PricePlaceholderFieldValue = typing___NewType(
        "PricePlaceholderFieldValue", builtin___int
    )
    type___PricePlaceholderFieldValue = PricePlaceholderFieldValue
    PricePlaceholderField: _PricePlaceholderField
    class _PricePlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 1)
        TYPE = typing___cast(PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 2)
        PRICE_QUALIFIER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 3
        )
        TRACKING_TEMPLATE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 4
        )
        LANGUAGE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 5
        )
        FINAL_URL_SUFFIX = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 6
        )
        ITEM_1_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 100
        )
        ITEM_1_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 101
        )
        ITEM_1_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 102
        )
        ITEM_1_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 103
        )
        ITEM_1_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 104
        )
        ITEM_1_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 105
        )
        ITEM_2_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 200
        )
        ITEM_2_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 201
        )
        ITEM_2_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 202
        )
        ITEM_2_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 203
        )
        ITEM_2_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 204
        )
        ITEM_2_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 205
        )
        ITEM_3_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 300
        )
        ITEM_3_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 301
        )
        ITEM_3_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 302
        )
        ITEM_3_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 303
        )
        ITEM_3_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 304
        )
        ITEM_3_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 305
        )
        ITEM_4_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 400
        )
        ITEM_4_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 401
        )
        ITEM_4_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 402
        )
        ITEM_4_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 403
        )
        ITEM_4_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 404
        )
        ITEM_4_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 405
        )
        ITEM_5_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 500
        )
        ITEM_5_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 501
        )
        ITEM_5_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 502
        )
        ITEM_5_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 503
        )
        ITEM_5_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 504
        )
        ITEM_5_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 505
        )
        ITEM_6_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 600
        )
        ITEM_6_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 601
        )
        ITEM_6_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 602
        )
        ITEM_6_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 603
        )
        ITEM_6_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 604
        )
        ITEM_6_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 605
        )
        ITEM_7_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 700
        )
        ITEM_7_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 701
        )
        ITEM_7_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 702
        )
        ITEM_7_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 703
        )
        ITEM_7_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 704
        )
        ITEM_7_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 705
        )
        ITEM_8_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 800
        )
        ITEM_8_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 801
        )
        ITEM_8_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 802
        )
        ITEM_8_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 803
        )
        ITEM_8_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 804
        )
        ITEM_8_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 805
        )
    UNSPECIFIED = typing___cast(PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 0)
    UNKNOWN = typing___cast(PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 1)
    TYPE = typing___cast(PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 2)
    PRICE_QUALIFIER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 3
    )
    TRACKING_TEMPLATE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 4
    )
    LANGUAGE = typing___cast(PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 5)
    FINAL_URL_SUFFIX = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 6
    )
    ITEM_1_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 100
    )
    ITEM_1_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 101
    )
    ITEM_1_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 102
    )
    ITEM_1_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 103
    )
    ITEM_1_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 104
    )
    ITEM_1_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 105
    )
    ITEM_2_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 200
    )
    ITEM_2_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 201
    )
    ITEM_2_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 202
    )
    ITEM_2_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 203
    )
    ITEM_2_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 204
    )
    ITEM_2_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 205
    )
    ITEM_3_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 300
    )
    ITEM_3_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 301
    )
    ITEM_3_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 302
    )
    ITEM_3_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 303
    )
    ITEM_3_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 304
    )
    ITEM_3_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 305
    )
    ITEM_4_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 400
    )
    ITEM_4_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 401
    )
    ITEM_4_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 402
    )
    ITEM_4_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 403
    )
    ITEM_4_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 404
    )
    ITEM_4_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 405
    )
    ITEM_5_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 500
    )
    ITEM_5_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 501
    )
    ITEM_5_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 502
    )
    ITEM_5_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 503
    )
    ITEM_5_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 504
    )
    ITEM_5_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 505
    )
    ITEM_6_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 600
    )
    ITEM_6_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 601
    )
    ITEM_6_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 602
    )
    ITEM_6_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 603
    )
    ITEM_6_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 604
    )
    ITEM_6_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 605
    )
    ITEM_7_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 700
    )
    ITEM_7_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 701
    )
    ITEM_7_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 702
    )
    ITEM_7_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 703
    )
    ITEM_7_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 704
    )
    ITEM_7_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 705
    )
    ITEM_8_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 800
    )
    ITEM_8_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 801
    )
    ITEM_8_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 802
    )
    ITEM_8_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 803
    )
    ITEM_8_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 804
    )
    ITEM_8_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 805
    )
    type___PricePlaceholderField = PricePlaceholderField
    def __init__(self,) -> None: ...

type___PricePlaceholderFieldEnum = PricePlaceholderFieldEnum



from typing import Any

class AdParameterServiceStub:
    GetAdParameter: Any = ...
    MutateAdParameters: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdParameterServiceServicer:
    def GetAdParameter(self, request: Any, context: Any) -> None: ...
    def MutateAdParameters(self, request: Any, context: Any) -> None: ...

def add_AdParameterServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



from typing import Any

class SharedSetServiceStub:
    GetSharedSet: Any = ...
    MutateSharedSets: Any = ...
    def __init__(self, channel: Any) -> None: ...

class SharedSetServiceServicer:
    def GetSharedSet(self, request: Any, context: Any) -> None: ...
    def MutateSharedSets(self, request: Any, context: Any) -> None: ...

def add_SharedSetServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.account_link_status_pb2 import (
    AccountLinkStatusEnum as google___ads___googleads___v4___enums___account_link_status_pb2___AccountLinkStatusEnum,
)
from google.ads.google_ads.v4.proto.enums.linked_account_type_pb2 import (
    LinkedAccountTypeEnum as google___ads___googleads___v4___enums___linked_account_type_pb2___LinkedAccountTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.mobile_app_vendor_pb2 import (
    MobileAppVendorEnum as google___ads___googleads___v4___enums___mobile_app_vendor_pb2___MobileAppVendorEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AccountLink(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    status: google___ads___googleads___v4___enums___account_link_status_pb2___AccountLinkStatusEnum.AccountLinkStatusValue = ...
    type: google___ads___googleads___v4___enums___linked_account_type_pb2___LinkedAccountTypeEnum.LinkedAccountTypeValue = ...
    @property
    def account_link_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def third_party_app_analytics(
        self,
    ) -> type___ThirdPartyAppAnalyticsLinkIdentifier: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        account_link_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v4___enums___account_link_status_pb2___AccountLinkStatusEnum.AccountLinkStatusValue
        ] = None,
        type: typing___Optional[
            google___ads___googleads___v4___enums___linked_account_type_pb2___LinkedAccountTypeEnum.LinkedAccountTypeValue
        ] = None,
        third_party_app_analytics: typing___Optional[
            type___ThirdPartyAppAnalyticsLinkIdentifier
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "account_link_id",
            b"account_link_id",
            "linked_account",
            b"linked_account",
            "third_party_app_analytics",
            b"third_party_app_analytics",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "account_link_id",
            b"account_link_id",
            "linked_account",
            b"linked_account",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "third_party_app_analytics",
            b"third_party_app_analytics",
            "type",
            b"type",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["linked_account", b"linked_account"],
    ) -> typing_extensions___Literal["third_party_app_analytics"]: ...

type___AccountLink = AccountLink

class ThirdPartyAppAnalyticsLinkIdentifier(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    app_vendor: google___ads___googleads___v4___enums___mobile_app_vendor_pb2___MobileAppVendorEnum.MobileAppVendorValue = ...
    @property
    def app_analytics_provider_id(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def app_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        app_analytics_provider_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        app_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        app_vendor: typing___Optional[
            google___ads___googleads___v4___enums___mobile_app_vendor_pb2___MobileAppVendorEnum.MobileAppVendorValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "app_analytics_provider_id",
            b"app_analytics_provider_id",
            "app_id",
            b"app_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "app_analytics_provider_id",
            b"app_analytics_provider_id",
            "app_id",
            b"app_id",
            "app_vendor",
            b"app_vendor",
        ],
    ) -> None: ...

type___ThirdPartyAppAnalyticsLinkIdentifier = ThirdPartyAppAnalyticsLinkIdentifier



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AssetTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AssetTypeValue = typing___NewType("AssetTypeValue", builtin___int)
    type___AssetTypeValue = AssetTypeValue
    AssetType: _AssetType
    class _AssetType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AssetTypeEnum.AssetTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AssetTypeEnum.AssetTypeValue, 0)
        UNKNOWN = typing___cast(AssetTypeEnum.AssetTypeValue, 1)
        YOUTUBE_VIDEO = typing___cast(AssetTypeEnum.AssetTypeValue, 2)
        MEDIA_BUNDLE = typing___cast(AssetTypeEnum.AssetTypeValue, 3)
        IMAGE = typing___cast(AssetTypeEnum.AssetTypeValue, 4)
        TEXT = typing___cast(AssetTypeEnum.AssetTypeValue, 5)
    UNSPECIFIED = typing___cast(AssetTypeEnum.AssetTypeValue, 0)
    UNKNOWN = typing___cast(AssetTypeEnum.AssetTypeValue, 1)
    YOUTUBE_VIDEO = typing___cast(AssetTypeEnum.AssetTypeValue, 2)
    MEDIA_BUNDLE = typing___cast(AssetTypeEnum.AssetTypeValue, 3)
    IMAGE = typing___cast(AssetTypeEnum.AssetTypeValue, 4)
    TEXT = typing___cast(AssetTypeEnum.AssetTypeValue, 5)
    type___AssetType = AssetType
    def __init__(self,) -> None: ...

type___AssetTypeEnum = AssetTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdCustomizerErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdCustomizerErrorValue = typing___NewType("AdCustomizerErrorValue", builtin___int)
    type___AdCustomizerErrorValue = AdCustomizerErrorValue
    AdCustomizerError: _AdCustomizerError
    class _AdCustomizerError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdCustomizerErrorEnum.AdCustomizerErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdCustomizerErrorEnum.AdCustomizerErrorValue, 0)
        UNKNOWN = typing___cast(AdCustomizerErrorEnum.AdCustomizerErrorValue, 1)
        COUNTDOWN_INVALID_DATE_FORMAT = typing___cast(
            AdCustomizerErrorEnum.AdCustomizerErrorValue, 2
        )
        COUNTDOWN_DATE_IN_PAST = typing___cast(
            AdCustomizerErrorEnum.AdCustomizerErrorValue, 3
        )
        COUNTDOWN_INVALID_LOCALE = typing___cast(
            AdCustomizerErrorEnum.AdCustomizerErrorValue, 4
        )
        COUNTDOWN_INVALID_START_DAYS_BEFORE = typing___cast(
            AdCustomizerErrorEnum.AdCustomizerErrorValue, 5
        )
        UNKNOWN_USER_LIST = typing___cast(
            AdCustomizerErrorEnum.AdCustomizerErrorValue, 6
        )
    UNSPECIFIED = typing___cast(AdCustomizerErrorEnum.AdCustomizerErrorValue, 0)
    UNKNOWN = typing___cast(AdCustomizerErrorEnum.AdCustomizerErrorValue, 1)
    COUNTDOWN_INVALID_DATE_FORMAT = typing___cast(
        AdCustomizerErrorEnum.AdCustomizerErrorValue, 2
    )
    COUNTDOWN_DATE_IN_PAST = typing___cast(
        AdCustomizerErrorEnum.AdCustomizerErrorValue, 3
    )
    COUNTDOWN_INVALID_LOCALE = typing___cast(
        AdCustomizerErrorEnum.AdCustomizerErrorValue, 4
    )
    COUNTDOWN_INVALID_START_DAYS_BEFORE = typing___cast(
        AdCustomizerErrorEnum.AdCustomizerErrorValue, 5
    )
    UNKNOWN_USER_LIST = typing___cast(AdCustomizerErrorEnum.AdCustomizerErrorValue, 6)
    type___AdCustomizerError = AdCustomizerError
    def __init__(self,) -> None: ...

type___AdCustomizerErrorEnum = AdCustomizerErrorEnum



from typing import Any

class ConversionAdjustmentUploadServiceStub:
    UploadConversionAdjustments: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ConversionAdjustmentUploadServiceServicer:
    def UploadConversionAdjustments(self, request: Any, context: Any) -> None: ...

def add_ConversionAdjustmentUploadServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UserLocationView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    country_criterion_id: builtin___int = ...
    targeting_location: builtin___bool = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        country_criterion_id: typing___Optional[builtin___int] = None,
        targeting_location: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_country_criterion_id",
            b"_country_criterion_id",
            "_targeting_location",
            b"_targeting_location",
            "country_criterion_id",
            b"country_criterion_id",
            "targeting_location",
            b"targeting_location",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_country_criterion_id",
            b"_country_criterion_id",
            "_targeting_location",
            b"_targeting_location",
            "country_criterion_id",
            b"country_criterion_id",
            "resource_name",
            b"resource_name",
            "targeting_location",
            b"targeting_location",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_country_criterion_id", b"_country_criterion_id"
        ],
    ) -> typing_extensions___Literal["country_criterion_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_targeting_location", b"_targeting_location"
        ],
    ) -> typing_extensions___Literal["targeting_location"]: ...

type___UserLocationView = UserLocationView



from typing import Any

class HotelGroupViewServiceStub:
    GetHotelGroupView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class HotelGroupViewServiceServicer:
    def GetHotelGroupView(self, request: Any, context: Any) -> None: ...

def add_HotelGroupViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



from typing import Any

class AdGroupExtensionSettingServiceStub:
    GetAdGroupExtensionSetting: Any = ...
    MutateAdGroupExtensionSettings: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupExtensionSettingServiceServicer:
    def GetAdGroupExtensionSetting(self, request: Any, context: Any) -> None: ...
    def MutateAdGroupExtensionSettings(self, request: Any, context: Any) -> None: ...

def add_AdGroupExtensionSettingServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignServingStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignServingStatusValue = typing___NewType(
        "CampaignServingStatusValue", builtin___int
    )
    type___CampaignServingStatusValue = CampaignServingStatusValue
    CampaignServingStatus: _CampaignServingStatus
    class _CampaignServingStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignServingStatusEnum.CampaignServingStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CampaignServingStatusEnum.CampaignServingStatusValue, 0
        )
        UNKNOWN = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 1)
        SERVING = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 2)
        NONE = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 3)
        ENDED = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 4)
        PENDING = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 5)
        SUSPENDED = typing___cast(
            CampaignServingStatusEnum.CampaignServingStatusValue, 6
        )
    UNSPECIFIED = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 0)
    UNKNOWN = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 1)
    SERVING = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 2)
    NONE = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 3)
    ENDED = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 4)
    PENDING = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 5)
    SUSPENDED = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 6)
    type___CampaignServingStatus = CampaignServingStatus
    def __init__(self,) -> None: ...

type___CampaignServingStatusEnum = CampaignServingStatusEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupCriterionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdGroupCriterionErrorValue = typing___NewType(
        "AdGroupCriterionErrorValue", builtin___int
    )
    type___AdGroupCriterionErrorValue = AdGroupCriterionErrorValue
    AdGroupCriterionError: _AdGroupCriterionError
    class _AdGroupCriterionError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 0
        )
        UNKNOWN = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 1)
        AD_GROUP_CRITERION_LABEL_DOES_NOT_EXIST = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 2
        )
        AD_GROUP_CRITERION_LABEL_ALREADY_EXISTS = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 3
        )
        CANNOT_ADD_LABEL_TO_NEGATIVE_CRITERION = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 4
        )
        TOO_MANY_OPERATIONS = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 5
        )
        CANT_UPDATE_NEGATIVE = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 6
        )
        CONCRETE_TYPE_REQUIRED = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 7
        )
        BID_INCOMPATIBLE_WITH_ADGROUP = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 8
        )
        CANNOT_TARGET_AND_EXCLUDE = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 9
        )
        ILLEGAL_URL = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 10
        )
        INVALID_KEYWORD_TEXT = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 11
        )
        INVALID_DESTINATION_URL = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 12
        )
        MISSING_DESTINATION_URL_TAG = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 13
        )
        KEYWORD_LEVEL_BID_NOT_SUPPORTED_FOR_MANUALCPM = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 14
        )
        INVALID_USER_STATUS = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 15
        )
        CANNOT_ADD_CRITERIA_TYPE = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 16
        )
        CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 17
        )
        CAMPAIGN_TYPE_NOT_COMPATIBLE_WITH_PARTIAL_FAILURE = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 27
        )
        OPERATIONS_FOR_TOO_MANY_SHOPPING_ADGROUPS = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 28
        )
        CANNOT_MODIFY_URL_FIELDS_WITH_DUPLICATE_ELEMENTS = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 29
        )
        CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 30
        )
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_MOBILE_URLS_EXIST = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 31
        )
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_APP_URLS_EXIST = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 32
        )
        CANNOT_CLEAR_FINAL_URLS_IF_TRACKING_URL_TEMPLATE_EXISTS = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 33
        )
        CANNOT_CLEAR_FINAL_URLS_IF_URL_CUSTOM_PARAMETERS_EXIST = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 34
        )
        CANNOT_SET_BOTH_DESTINATION_URL_AND_FINAL_URLS = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 35
        )
        CANNOT_SET_BOTH_DESTINATION_URL_AND_TRACKING_URL_TEMPLATE = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 36
        )
        FINAL_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 37
        )
        FINAL_MOBILE_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 38
        )
        INVALID_LISTING_GROUP_HIERARCHY = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 39
        )
        LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 40
        )
        LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 41
        )
        LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 42
        )
        LISTING_GROUP_ALREADY_EXISTS = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 43
        )
        LISTING_GROUP_DOES_NOT_EXIST = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 44
        )
        LISTING_GROUP_CANNOT_BE_REMOVED = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 45
        )
        INVALID_LISTING_GROUP_TYPE = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 46
        )
        LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID = typing___cast(
            AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 47
        )
    UNSPECIFIED = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 0)
    UNKNOWN = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 1)
    AD_GROUP_CRITERION_LABEL_DOES_NOT_EXIST = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 2
    )
    AD_GROUP_CRITERION_LABEL_ALREADY_EXISTS = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 3
    )
    CANNOT_ADD_LABEL_TO_NEGATIVE_CRITERION = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 4
    )
    TOO_MANY_OPERATIONS = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 5
    )
    CANT_UPDATE_NEGATIVE = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 6
    )
    CONCRETE_TYPE_REQUIRED = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 7
    )
    BID_INCOMPATIBLE_WITH_ADGROUP = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 8
    )
    CANNOT_TARGET_AND_EXCLUDE = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 9
    )
    ILLEGAL_URL = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 10
    )
    INVALID_KEYWORD_TEXT = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 11
    )
    INVALID_DESTINATION_URL = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 12
    )
    MISSING_DESTINATION_URL_TAG = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 13
    )
    KEYWORD_LEVEL_BID_NOT_SUPPORTED_FOR_MANUALCPM = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 14
    )
    INVALID_USER_STATUS = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 15
    )
    CANNOT_ADD_CRITERIA_TYPE = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 16
    )
    CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 17
    )
    CAMPAIGN_TYPE_NOT_COMPATIBLE_WITH_PARTIAL_FAILURE = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 27
    )
    OPERATIONS_FOR_TOO_MANY_SHOPPING_ADGROUPS = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 28
    )
    CANNOT_MODIFY_URL_FIELDS_WITH_DUPLICATE_ELEMENTS = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 29
    )
    CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 30
    )
    CANNOT_CLEAR_FINAL_URLS_IF_FINAL_MOBILE_URLS_EXIST = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 31
    )
    CANNOT_CLEAR_FINAL_URLS_IF_FINAL_APP_URLS_EXIST = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 32
    )
    CANNOT_CLEAR_FINAL_URLS_IF_TRACKING_URL_TEMPLATE_EXISTS = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 33
    )
    CANNOT_CLEAR_FINAL_URLS_IF_URL_CUSTOM_PARAMETERS_EXIST = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 34
    )
    CANNOT_SET_BOTH_DESTINATION_URL_AND_FINAL_URLS = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 35
    )
    CANNOT_SET_BOTH_DESTINATION_URL_AND_TRACKING_URL_TEMPLATE = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 36
    )
    FINAL_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 37
    )
    FINAL_MOBILE_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 38
    )
    INVALID_LISTING_GROUP_HIERARCHY = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 39
    )
    LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 40
    )
    LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 41
    )
    LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 42
    )
    LISTING_GROUP_ALREADY_EXISTS = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 43
    )
    LISTING_GROUP_DOES_NOT_EXIST = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 44
    )
    LISTING_GROUP_CANNOT_BE_REMOVED = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 45
    )
    INVALID_LISTING_GROUP_TYPE = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 46
    )
    LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID = typing___cast(
        AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue, 47
    )
    type___AdGroupCriterionError = AdGroupCriterionError
    def __init__(self,) -> None: ...

type___AdGroupCriterionErrorEnum = AdGroupCriterionErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.common.criteria_pb2 import (
    DeviceInfo as google___ads___googleads___v3___common___criteria_pb2___DeviceInfo,
    HotelAdvanceBookingWindowInfo as google___ads___googleads___v3___common___criteria_pb2___HotelAdvanceBookingWindowInfo,
    HotelCheckInDayInfo as google___ads___googleads___v3___common___criteria_pb2___HotelCheckInDayInfo,
    HotelDateSelectionTypeInfo as google___ads___googleads___v3___common___criteria_pb2___HotelDateSelectionTypeInfo,
    HotelLengthOfStayInfo as google___ads___googleads___v3___common___criteria_pb2___HotelLengthOfStayInfo,
    PreferredContentInfo as google___ads___googleads___v3___common___criteria_pb2___PreferredContentInfo,
)
from google.ads.google_ads.v3.proto.enums.bid_modifier_source_pb2 import (
    BidModifierSourceEnum as google___ads___googleads___v3___enums___bid_modifier_source_pb2___BidModifierSourceEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupBidModifier(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    bid_modifier_source: google___ads___googleads___v3___enums___bid_modifier_source_pb2___BidModifierSourceEnum.BidModifierSourceValue = ...
    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def criterion_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def bid_modifier(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def base_ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def hotel_date_selection_type(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___HotelDateSelectionTypeInfo: ...
    @property
    def hotel_advance_booking_window(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___HotelAdvanceBookingWindowInfo: ...
    @property
    def hotel_length_of_stay(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___HotelLengthOfStayInfo: ...
    @property
    def hotel_check_in_day(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___HotelCheckInDayInfo: ...
    @property
    def device(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___DeviceInfo: ...
    @property
    def preferred_content(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___PreferredContentInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        ad_group: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        criterion_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        bid_modifier: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        base_ad_group: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        bid_modifier_source: typing___Optional[
            google___ads___googleads___v3___enums___bid_modifier_source_pb2___BidModifierSourceEnum.BidModifierSourceValue
        ] = None,
        hotel_date_selection_type: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___HotelDateSelectionTypeInfo
        ] = None,
        hotel_advance_booking_window: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___HotelAdvanceBookingWindowInfo
        ] = None,
        hotel_length_of_stay: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___HotelLengthOfStayInfo
        ] = None,
        hotel_check_in_day: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___HotelCheckInDayInfo
        ] = None,
        device: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___DeviceInfo
        ] = None,
        preferred_content: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___PreferredContentInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group",
            b"ad_group",
            "base_ad_group",
            b"base_ad_group",
            "bid_modifier",
            b"bid_modifier",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "device",
            b"device",
            "hotel_advance_booking_window",
            b"hotel_advance_booking_window",
            "hotel_check_in_day",
            b"hotel_check_in_day",
            "hotel_date_selection_type",
            b"hotel_date_selection_type",
            "hotel_length_of_stay",
            b"hotel_length_of_stay",
            "preferred_content",
            b"preferred_content",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group",
            b"ad_group",
            "base_ad_group",
            b"base_ad_group",
            "bid_modifier",
            b"bid_modifier",
            "bid_modifier_source",
            b"bid_modifier_source",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "device",
            b"device",
            "hotel_advance_booking_window",
            b"hotel_advance_booking_window",
            "hotel_check_in_day",
            b"hotel_check_in_day",
            "hotel_date_selection_type",
            b"hotel_date_selection_type",
            "hotel_length_of_stay",
            b"hotel_length_of_stay",
            "preferred_content",
            b"preferred_content",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["criterion", b"criterion"]
    ) -> typing_extensions___Literal[
        "hotel_date_selection_type",
        "hotel_advance_booking_window",
        "hotel_length_of_stay",
        "hotel_check_in_day",
        "device",
        "preferred_content",
    ]: ...

type___AdGroupBidModifier = AdGroupBidModifier



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetMobileAppCategoryConstantRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetMobileAppCategoryConstantRequest = GetMobileAppCategoryConstantRequest



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.field_mask_pb2 import (
    FieldMask as google___protobuf___field_mask_pb2___FieldMask,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.resources.customer_client_link_pb2 import (
    CustomerClientLink as google___ads___googleads___v3___resources___customer_client_link_pb2___CustomerClientLink,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetCustomerClientLinkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetCustomerClientLinkRequest = GetCustomerClientLinkRequest

class MutateCustomerClientLinkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    @property
    def operation(self) -> type___CustomerClientLinkOperation: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        operation: typing___Optional[type___CustomerClientLinkOperation] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["operation", b"operation"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id", b"customer_id", "operation", b"operation"
        ],
    ) -> None: ...

type___MutateCustomerClientLinkRequest = MutateCustomerClientLinkRequest

class CustomerClientLinkOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def update_mask(self) -> google___protobuf___field_mask_pb2___FieldMask: ...
    @property
    def create(
        self,
    ) -> google___ads___googleads___v3___resources___customer_client_link_pb2___CustomerClientLink: ...
    @property
    def update(
        self,
    ) -> google___ads___googleads___v3___resources___customer_client_link_pb2___CustomerClientLink: ...
    def __init__(
        self,
        *,
        update_mask: typing___Optional[
            google___protobuf___field_mask_pb2___FieldMask
        ] = None,
        create: typing___Optional[
            google___ads___googleads___v3___resources___customer_client_link_pb2___CustomerClientLink
        ] = None,
        update: typing___Optional[
            google___ads___googleads___v3___resources___customer_client_link_pb2___CustomerClientLink
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["operation", b"operation"]
    ) -> typing_extensions___Literal["create", "update"]: ...

type___CustomerClientLinkOperation = CustomerClientLinkOperation

class MutateCustomerClientLinkResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def result(self) -> type___MutateCustomerClientLinkResult: ...
    def __init__(
        self,
        *,
        result: typing___Optional[type___MutateCustomerClientLinkResult] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["result", b"result"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["result", b"result"]
    ) -> None: ...

type___MutateCustomerClientLinkResponse = MutateCustomerClientLinkResponse

class MutateCustomerClientLinkResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___MutateCustomerClientLinkResult = MutateCustomerClientLinkResult



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomPlaceholderFieldValue = typing___NewType(
        "CustomPlaceholderFieldValue", builtin___int
    )
    type___CustomPlaceholderFieldValue = CustomPlaceholderFieldValue
    CustomPlaceholderField: _CustomPlaceholderField
    class _CustomPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 1
        )
        ID = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 2)
        ID2 = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 3)
        ITEM_TITLE = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 4
        )
        ITEM_SUBTITLE = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 5
        )
        ITEM_DESCRIPTION = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 6
        )
        ITEM_ADDRESS = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 7
        )
        PRICE = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 8)
        FORMATTED_PRICE = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 9
        )
        SALE_PRICE = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 10
        )
        FORMATTED_SALE_PRICE = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 11
        )
        IMAGE_URL = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 12
        )
        ITEM_CATEGORY = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 13
        )
        FINAL_URLS = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 14
        )
        FINAL_MOBILE_URLS = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 15
        )
        TRACKING_URL = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 16
        )
        CONTEXTUAL_KEYWORDS = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 17
        )
        ANDROID_APP_LINK = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 18
        )
        SIMILAR_IDS = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 19
        )
        IOS_APP_LINK = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 20
        )
        IOS_APP_STORE_ID = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 21
        )
    UNSPECIFIED = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 1)
    ID = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 2)
    ID2 = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 3)
    ITEM_TITLE = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 4
    )
    ITEM_SUBTITLE = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 5
    )
    ITEM_DESCRIPTION = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 6
    )
    ITEM_ADDRESS = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 7
    )
    PRICE = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 8)
    FORMATTED_PRICE = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 9
    )
    SALE_PRICE = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 10
    )
    FORMATTED_SALE_PRICE = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 11
    )
    IMAGE_URL = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 12
    )
    ITEM_CATEGORY = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 13
    )
    FINAL_URLS = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 14
    )
    FINAL_MOBILE_URLS = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 15
    )
    TRACKING_URL = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 16
    )
    CONTEXTUAL_KEYWORDS = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 17
    )
    ANDROID_APP_LINK = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 18
    )
    SIMILAR_IDS = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 19
    )
    IOS_APP_LINK = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 20
    )
    IOS_APP_STORE_ID = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 21
    )
    type___CustomPlaceholderField = CustomPlaceholderField
    def __init__(self,) -> None: ...

type___CustomPlaceholderFieldEnum = CustomPlaceholderFieldEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.common.criteria_pb2 import (
    AgeRangeInfo as google___ads___googleads___v3___common___criteria_pb2___AgeRangeInfo,
    AppPaymentModelInfo as google___ads___googleads___v3___common___criteria_pb2___AppPaymentModelInfo,
    CustomAffinityInfo as google___ads___googleads___v3___common___criteria_pb2___CustomAffinityInfo,
    CustomIntentInfo as google___ads___googleads___v3___common___criteria_pb2___CustomIntentInfo,
    GenderInfo as google___ads___googleads___v3___common___criteria_pb2___GenderInfo,
    IncomeRangeInfo as google___ads___googleads___v3___common___criteria_pb2___IncomeRangeInfo,
    KeywordInfo as google___ads___googleads___v3___common___criteria_pb2___KeywordInfo,
    ListingGroupInfo as google___ads___googleads___v3___common___criteria_pb2___ListingGroupInfo,
    MobileAppCategoryInfo as google___ads___googleads___v3___common___criteria_pb2___MobileAppCategoryInfo,
    MobileApplicationInfo as google___ads___googleads___v3___common___criteria_pb2___MobileApplicationInfo,
    ParentalStatusInfo as google___ads___googleads___v3___common___criteria_pb2___ParentalStatusInfo,
    PlacementInfo as google___ads___googleads___v3___common___criteria_pb2___PlacementInfo,
    TopicInfo as google___ads___googleads___v3___common___criteria_pb2___TopicInfo,
    UserInterestInfo as google___ads___googleads___v3___common___criteria_pb2___UserInterestInfo,
    UserListInfo as google___ads___googleads___v3___common___criteria_pb2___UserListInfo,
    WebpageInfo as google___ads___googleads___v3___common___criteria_pb2___WebpageInfo,
    YouTubeChannelInfo as google___ads___googleads___v3___common___criteria_pb2___YouTubeChannelInfo,
    YouTubeVideoInfo as google___ads___googleads___v3___common___criteria_pb2___YouTubeVideoInfo,
)
from google.ads.google_ads.v3.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v3___common___custom_parameter_pb2___CustomParameter,
)
from google.ads.google_ads.v3.proto.enums.ad_group_criterion_approval_status_pb2 import (
    AdGroupCriterionApprovalStatusEnum as google___ads___googleads___v3___enums___ad_group_criterion_approval_status_pb2___AdGroupCriterionApprovalStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.ad_group_criterion_status_pb2 import (
    AdGroupCriterionStatusEnum as google___ads___googleads___v3___enums___ad_group_criterion_status_pb2___AdGroupCriterionStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.bidding_source_pb2 import (
    BiddingSourceEnum as google___ads___googleads___v3___enums___bidding_source_pb2___BiddingSourceEnum,
)
from google.ads.google_ads.v3.proto.enums.criterion_system_serving_status_pb2 import (
    CriterionSystemServingStatusEnum as google___ads___googleads___v3___enums___criterion_system_serving_status_pb2___CriterionSystemServingStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.criterion_type_pb2 import (
    CriterionTypeEnum as google___ads___googleads___v3___enums___criterion_type_pb2___CriterionTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.quality_score_bucket_pb2 import (
    QualityScoreBucketEnum as google___ads___googleads___v3___enums___quality_score_bucket_pb2___QualityScoreBucketEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupCriterion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class QualityInfo(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        creative_quality_score: google___ads___googleads___v3___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucketValue = ...
        post_click_quality_score: google___ads___googleads___v3___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucketValue = ...
        search_predicted_ctr: google___ads___googleads___v3___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucketValue = ...
        @property
        def quality_score(self) -> google___protobuf___wrappers_pb2___Int32Value: ...
        def __init__(
            self,
            *,
            quality_score: typing___Optional[
                google___protobuf___wrappers_pb2___Int32Value
            ] = None,
            creative_quality_score: typing___Optional[
                google___ads___googleads___v3___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucketValue
            ] = None,
            post_click_quality_score: typing___Optional[
                google___ads___googleads___v3___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucketValue
            ] = None,
            search_predicted_ctr: typing___Optional[
                google___ads___googleads___v3___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucketValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal["quality_score", b"quality_score"],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "creative_quality_score",
                b"creative_quality_score",
                "post_click_quality_score",
                b"post_click_quality_score",
                "quality_score",
                b"quality_score",
                "search_predicted_ctr",
                b"search_predicted_ctr",
            ],
        ) -> None: ...
    type___QualityInfo = QualityInfo
    class PositionEstimates(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def first_page_cpc_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def first_position_cpc_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def top_of_page_cpc_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def estimated_add_clicks_at_first_position_cpc(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def estimated_add_cost_at_first_position_cpc(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        def __init__(
            self,
            *,
            first_page_cpc_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            first_position_cpc_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            top_of_page_cpc_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            estimated_add_clicks_at_first_position_cpc: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            estimated_add_cost_at_first_position_cpc: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "estimated_add_clicks_at_first_position_cpc",
                b"estimated_add_clicks_at_first_position_cpc",
                "estimated_add_cost_at_first_position_cpc",
                b"estimated_add_cost_at_first_position_cpc",
                "first_page_cpc_micros",
                b"first_page_cpc_micros",
                "first_position_cpc_micros",
                b"first_position_cpc_micros",
                "top_of_page_cpc_micros",
                b"top_of_page_cpc_micros",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "estimated_add_clicks_at_first_position_cpc",
                b"estimated_add_clicks_at_first_position_cpc",
                "estimated_add_cost_at_first_position_cpc",
                b"estimated_add_cost_at_first_position_cpc",
                "first_page_cpc_micros",
                b"first_page_cpc_micros",
                "first_position_cpc_micros",
                b"first_position_cpc_micros",
                "top_of_page_cpc_micros",
                b"top_of_page_cpc_micros",
            ],
        ) -> None: ...
    type___PositionEstimates = PositionEstimates

    resource_name: typing___Text = ...
    status: google___ads___googleads___v3___enums___ad_group_criterion_status_pb2___AdGroupCriterionStatusEnum.AdGroupCriterionStatusValue = ...
    type: google___ads___googleads___v3___enums___criterion_type_pb2___CriterionTypeEnum.CriterionTypeValue = ...
    system_serving_status: google___ads___googleads___v3___enums___criterion_system_serving_status_pb2___CriterionSystemServingStatusEnum.CriterionSystemServingStatusValue = ...
    approval_status: google___ads___googleads___v3___enums___ad_group_criterion_approval_status_pb2___AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatusValue = ...
    effective_cpc_bid_source: google___ads___googleads___v3___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSourceValue = ...
    effective_cpm_bid_source: google___ads___googleads___v3___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSourceValue = ...
    effective_cpv_bid_source: google___ads___googleads___v3___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSourceValue = ...
    effective_percent_cpc_bid_source: google___ads___googleads___v3___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSourceValue = ...
    @property
    def criterion_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def quality_info(self) -> type___AdGroupCriterion.QualityInfo: ...
    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def negative(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def bid_modifier(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def cpm_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def cpv_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def percent_cpc_bid_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def effective_cpc_bid_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def effective_cpm_bid_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def effective_cpv_bid_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def effective_percent_cpc_bid_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def position_estimates(self) -> type___AdGroupCriterion.PositionEstimates: ...
    @property
    def final_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def final_mobile_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def tracking_url_template(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v3___common___custom_parameter_pb2___CustomParameter
    ]: ...
    @property
    def keyword(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___KeywordInfo: ...
    @property
    def placement(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___PlacementInfo: ...
    @property
    def mobile_app_category(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___MobileAppCategoryInfo: ...
    @property
    def mobile_application(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___MobileApplicationInfo: ...
    @property
    def listing_group(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___ListingGroupInfo: ...
    @property
    def age_range(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___AgeRangeInfo: ...
    @property
    def gender(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___GenderInfo: ...
    @property
    def income_range(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___IncomeRangeInfo: ...
    @property
    def parental_status(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___ParentalStatusInfo: ...
    @property
    def user_list(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___UserListInfo: ...
    @property
    def youtube_video(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___YouTubeVideoInfo: ...
    @property
    def youtube_channel(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___YouTubeChannelInfo: ...
    @property
    def topic(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___TopicInfo: ...
    @property
    def user_interest(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___UserInterestInfo: ...
    @property
    def webpage(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___WebpageInfo: ...
    @property
    def app_payment_model(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___AppPaymentModelInfo: ...
    @property
    def custom_affinity(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___CustomAffinityInfo: ...
    @property
    def custom_intent(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___CustomIntentInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        criterion_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v3___enums___ad_group_criterion_status_pb2___AdGroupCriterionStatusEnum.AdGroupCriterionStatusValue
        ] = None,
        quality_info: typing___Optional[type___AdGroupCriterion.QualityInfo] = None,
        ad_group: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        type: typing___Optional[
            google___ads___googleads___v3___enums___criterion_type_pb2___CriterionTypeEnum.CriterionTypeValue
        ] = None,
        negative: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        system_serving_status: typing___Optional[
            google___ads___googleads___v3___enums___criterion_system_serving_status_pb2___CriterionSystemServingStatusEnum.CriterionSystemServingStatusValue
        ] = None,
        approval_status: typing___Optional[
            google___ads___googleads___v3___enums___ad_group_criterion_approval_status_pb2___AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatusValue
        ] = None,
        bid_modifier: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        cpc_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        cpm_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        cpv_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        percent_cpc_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        effective_cpc_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        effective_cpm_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        effective_cpv_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        effective_percent_cpc_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        effective_cpc_bid_source: typing___Optional[
            google___ads___googleads___v3___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSourceValue
        ] = None,
        effective_cpm_bid_source: typing___Optional[
            google___ads___googleads___v3___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSourceValue
        ] = None,
        effective_cpv_bid_source: typing___Optional[
            google___ads___googleads___v3___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSourceValue
        ] = None,
        effective_percent_cpc_bid_source: typing___Optional[
            google___ads___googleads___v3___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSourceValue
        ] = None,
        position_estimates: typing___Optional[
            type___AdGroupCriterion.PositionEstimates
        ] = None,
        final_urls: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        final_mobile_urls: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        final_url_suffix: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        tracking_url_template: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        url_custom_parameters: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___common___custom_parameter_pb2___CustomParameter
            ]
        ] = None,
        keyword: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___KeywordInfo
        ] = None,
        placement: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___PlacementInfo
        ] = None,
        mobile_app_category: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___MobileAppCategoryInfo
        ] = None,
        mobile_application: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___MobileApplicationInfo
        ] = None,
        listing_group: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___ListingGroupInfo
        ] = None,
        age_range: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___AgeRangeInfo
        ] = None,
        gender: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___GenderInfo
        ] = None,
        income_range: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___IncomeRangeInfo
        ] = None,
        parental_status: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___ParentalStatusInfo
        ] = None,
        user_list: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___UserListInfo
        ] = None,
        youtube_video: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___YouTubeVideoInfo
        ] = None,
        youtube_channel: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___YouTubeChannelInfo
        ] = None,
        topic: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___TopicInfo
        ] = None,
        user_interest: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___UserInterestInfo
        ] = None,
        webpage: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___WebpageInfo
        ] = None,
        app_payment_model: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___AppPaymentModelInfo
        ] = None,
        custom_affinity: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___CustomAffinityInfo
        ] = None,
        custom_intent: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___CustomIntentInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group",
            b"ad_group",
            "age_range",
            b"age_range",
            "app_payment_model",
            b"app_payment_model",
            "bid_modifier",
            b"bid_modifier",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "cpm_bid_micros",
            b"cpm_bid_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "custom_affinity",
            b"custom_affinity",
            "custom_intent",
            b"custom_intent",
            "effective_cpc_bid_micros",
            b"effective_cpc_bid_micros",
            "effective_cpm_bid_micros",
            b"effective_cpm_bid_micros",
            "effective_cpv_bid_micros",
            b"effective_cpv_bid_micros",
            "effective_percent_cpc_bid_micros",
            b"effective_percent_cpc_bid_micros",
            "final_url_suffix",
            b"final_url_suffix",
            "gender",
            b"gender",
            "income_range",
            b"income_range",
            "keyword",
            b"keyword",
            "listing_group",
            b"listing_group",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "negative",
            b"negative",
            "parental_status",
            b"parental_status",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "placement",
            b"placement",
            "position_estimates",
            b"position_estimates",
            "quality_info",
            b"quality_info",
            "topic",
            b"topic",
            "tracking_url_template",
            b"tracking_url_template",
            "user_interest",
            b"user_interest",
            "user_list",
            b"user_list",
            "webpage",
            b"webpage",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group",
            b"ad_group",
            "age_range",
            b"age_range",
            "app_payment_model",
            b"app_payment_model",
            "approval_status",
            b"approval_status",
            "bid_modifier",
            b"bid_modifier",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "cpm_bid_micros",
            b"cpm_bid_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "custom_affinity",
            b"custom_affinity",
            "custom_intent",
            b"custom_intent",
            "effective_cpc_bid_micros",
            b"effective_cpc_bid_micros",
            "effective_cpc_bid_source",
            b"effective_cpc_bid_source",
            "effective_cpm_bid_micros",
            b"effective_cpm_bid_micros",
            "effective_cpm_bid_source",
            b"effective_cpm_bid_source",
            "effective_cpv_bid_micros",
            b"effective_cpv_bid_micros",
            "effective_cpv_bid_source",
            b"effective_cpv_bid_source",
            "effective_percent_cpc_bid_micros",
            b"effective_percent_cpc_bid_micros",
            "effective_percent_cpc_bid_source",
            b"effective_percent_cpc_bid_source",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_url_suffix",
            b"final_url_suffix",
            "final_urls",
            b"final_urls",
            "gender",
            b"gender",
            "income_range",
            b"income_range",
            "keyword",
            b"keyword",
            "listing_group",
            b"listing_group",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "negative",
            b"negative",
            "parental_status",
            b"parental_status",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "placement",
            b"placement",
            "position_estimates",
            b"position_estimates",
            "quality_info",
            b"quality_info",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "system_serving_status",
            b"system_serving_status",
            "topic",
            b"topic",
            "tracking_url_template",
            b"tracking_url_template",
            "type",
            b"type",
            "url_custom_parameters",
            b"url_custom_parameters",
            "user_interest",
            b"user_interest",
            "user_list",
            b"user_list",
            "webpage",
            b"webpage",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["criterion", b"criterion"]
    ) -> typing_extensions___Literal[
        "keyword",
        "placement",
        "mobile_app_category",
        "mobile_application",
        "listing_group",
        "age_range",
        "gender",
        "income_range",
        "parental_status",
        "user_list",
        "youtube_video",
        "youtube_channel",
        "topic",
        "user_interest",
        "webpage",
        "app_payment_model",
        "custom_affinity",
        "custom_intent",
    ]: ...

type___AdGroupCriterion = AdGroupCriterion



from typing import Union

import grpc  # type: ignore

from google.ads.google_ads.v3.proto.errors.errors_pb2 import (
    GoogleAdsFailure as GoogleAdsFailureV3,
)
from google.ads.google_ads.v4.proto.errors.errors_pb2 import (
    GoogleAdsFailure as GoogleAdsFailureV4,
)
from google.ads.google_ads.v5.proto.errors.errors_pb2 import (
    GoogleAdsFailure as GoogleAdsFailureV5,
)
from google.ads.google_ads.v6.proto.errors.errors_pb2 import (
    GoogleAdsFailure as GoogleAdsFailureV6,
)

GoogleAdsFailure = Union[
    GoogleAdsFailureV3, GoogleAdsFailureV4, GoogleAdsFailureV5, GoogleAdsFailureV6
]

class GoogleAdsException(Exception):
    error: grpc.RpcError = ...
    call: grpc.Call = ...
    failure: GoogleAdsFailure = ...
    request_id: str = ...
    def __init__(
        self,
        error: grpc.RpcError,
        call: grpc.Call,
        failure: GoogleAdsFailure,
        request_id: str,
    ) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignExperimentTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignExperimentTypeValue = typing___NewType(
        "CampaignExperimentTypeValue", builtin___int
    )
    type___CampaignExperimentTypeValue = CampaignExperimentTypeValue
    CampaignExperimentType: _CampaignExperimentType
    class _CampaignExperimentType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignExperimentTypeEnum.CampaignExperimentTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 0
        )
        UNKNOWN = typing___cast(
            CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 1
        )
        BASE = typing___cast(CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 2)
        DRAFT = typing___cast(CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 3)
        EXPERIMENT = typing___cast(
            CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 4
        )
    UNSPECIFIED = typing___cast(
        CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 0
    )
    UNKNOWN = typing___cast(CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 1)
    BASE = typing___cast(CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 2)
    DRAFT = typing___cast(CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 3)
    EXPERIMENT = typing___cast(
        CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 4
    )
    type___CampaignExperimentType = CampaignExperimentType
    def __init__(self,) -> None: ...

type___CampaignExperimentTypeEnum = CampaignExperimentTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SitelinkPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    SitelinkPlaceholderFieldValue = typing___NewType(
        "SitelinkPlaceholderFieldValue", builtin___int
    )
    type___SitelinkPlaceholderFieldValue = SitelinkPlaceholderFieldValue
    SitelinkPlaceholderField: _SitelinkPlaceholderField
    class _SitelinkPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 1
        )
        TEXT = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 2
        )
        LINE_1 = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 3
        )
        LINE_2 = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 4
        )
        FINAL_URLS = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 5
        )
        FINAL_MOBILE_URLS = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 6
        )
        TRACKING_URL = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 7
        )
        FINAL_URL_SUFFIX = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 8
        )
    UNSPECIFIED = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 1
    )
    TEXT = typing___cast(SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 2)
    LINE_1 = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 3
    )
    LINE_2 = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 4
    )
    FINAL_URLS = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 5
    )
    FINAL_MOBILE_URLS = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 6
    )
    TRACKING_URL = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 7
    )
    FINAL_URL_SUFFIX = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 8
    )
    type___SitelinkPlaceholderField = SitelinkPlaceholderField
    def __init__(self,) -> None: ...

type___SitelinkPlaceholderFieldEnum = SitelinkPlaceholderFieldEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AffiliateLocationPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AffiliateLocationPlaceholderFieldValue = typing___NewType(
        "AffiliateLocationPlaceholderFieldValue", builtin___int
    )
    type___AffiliateLocationPlaceholderFieldValue = (
        AffiliateLocationPlaceholderFieldValue
    )
    AffiliateLocationPlaceholderField: _AffiliateLocationPlaceholderField
    class _AffiliateLocationPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            0,
        )
        UNKNOWN = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            1,
        )
        BUSINESS_NAME = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            2,
        )
        ADDRESS_LINE_1 = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            3,
        )
        ADDRESS_LINE_2 = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            4,
        )
        CITY = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            5,
        )
        PROVINCE = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            6,
        )
        POSTAL_CODE = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            7,
        )
        COUNTRY_CODE = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            8,
        )
        PHONE_NUMBER = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            9,
        )
        LANGUAGE_CODE = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            10,
        )
        CHAIN_ID = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            11,
        )
        CHAIN_NAME = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            12,
        )
    UNSPECIFIED = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 1
    )
    BUSINESS_NAME = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 2
    )
    ADDRESS_LINE_1 = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 3
    )
    ADDRESS_LINE_2 = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 4
    )
    CITY = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 5
    )
    PROVINCE = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 6
    )
    POSTAL_CODE = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 7
    )
    COUNTRY_CODE = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 8
    )
    PHONE_NUMBER = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 9
    )
    LANGUAGE_CODE = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 10
    )
    CHAIN_ID = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 11
    )
    CHAIN_NAME = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 12
    )
    type___AffiliateLocationPlaceholderField = AffiliateLocationPlaceholderField
    def __init__(self,) -> None: ...

type___AffiliateLocationPlaceholderFieldEnum = AffiliateLocationPlaceholderFieldEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class InteractionEventTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    InteractionEventTypeValue = typing___NewType(
        "InteractionEventTypeValue", builtin___int
    )
    type___InteractionEventTypeValue = InteractionEventTypeValue
    InteractionEventType: _InteractionEventType
    class _InteractionEventType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            InteractionEventTypeEnum.InteractionEventTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            InteractionEventTypeEnum.InteractionEventTypeValue, 0
        )
        UNKNOWN = typing___cast(InteractionEventTypeEnum.InteractionEventTypeValue, 1)
        CLICK = typing___cast(InteractionEventTypeEnum.InteractionEventTypeValue, 2)
        ENGAGEMENT = typing___cast(
            InteractionEventTypeEnum.InteractionEventTypeValue, 3
        )
        VIDEO_VIEW = typing___cast(
            InteractionEventTypeEnum.InteractionEventTypeValue, 4
        )
        NONE = typing___cast(InteractionEventTypeEnum.InteractionEventTypeValue, 5)
    UNSPECIFIED = typing___cast(InteractionEventTypeEnum.InteractionEventTypeValue, 0)
    UNKNOWN = typing___cast(InteractionEventTypeEnum.InteractionEventTypeValue, 1)
    CLICK = typing___cast(InteractionEventTypeEnum.InteractionEventTypeValue, 2)
    ENGAGEMENT = typing___cast(InteractionEventTypeEnum.InteractionEventTypeValue, 3)
    VIDEO_VIEW = typing___cast(InteractionEventTypeEnum.InteractionEventTypeValue, 4)
    NONE = typing___cast(InteractionEventTypeEnum.InteractionEventTypeValue, 5)
    type___InteractionEventType = InteractionEventType
    def __init__(self,) -> None: ...

type___InteractionEventTypeEnum = InteractionEventTypeEnum
